package WebGUI::i18n::Spanish::Asset_Event;
use utf8;
our $I18N = {
  'After' => {
    'lastUpdated' => '1257423710',
    'message' => 'Después de'
  },
  'By date' => {
    'lastUpdated' => '1257423718',
    'message' => 'Por fecha'
  },
  'Daily' => {
    'lastUpdated' => '1257423725',
    'message' => 'Diario'
  },
  'Every' => {
    'lastUpdated' => '1257423731',
    'message' => 'Cada'
  },
  'Every N months on' => {
    'lastUpdated' => '1257423752',
    'message' => 'Cada %s mes(es) el'
  },
  'Every N weeks on' => {
    'lastUpdated' => '1257423763',
    'message' => 'Cada %s semana(s) el'
  },
  'Every N years on' => {
    'lastUpdated' => '1257423778',
    'message' => 'Cada %s año(s) el'
  },
  'Monthly' => {
    'lastUpdated' => '1257423793',
    'message' => 'Mensual'
  },
  'No end' => {
    'lastUpdated' => '1257423808',
    'message' => 'Indefinido'
  },
  'No specific time' => {
    'lastUpdated' => '1257423827',
    'message' => 'Todo el día'
  },
  'Specific start/end time' => {
    'lastUpdated' => '1257423849',
    'message' => 'Hora específica de inicio/final'
  },
  'The event end date must be after the event start date.' => {
    'lastUpdated' => '1252515472',
    'message' => 'La fecha de Fin del Evento debe ser posterior a la fecha de Inicio del Evento.'
  },
  'The event end time must be after the event start time.' => {
    'lastUpdated' => '1252515503',
    'message' => 'La hora de Fin del Evento debe ser posterior a la hora de Inicio del Evento.'
  },
  'UserDefinedN' => {
    'lastUpdated' => '1204234873',
    'message' => '<div id="result_box" dir="ltr">Para cada uno de los 5 campos Definido por el usuario, el valor de ese campo.</div>'
  },
  'Weekday(s)' => {
    'lastUpdated' => '1257423877',
    'message' => 'Día(s) de la semana'
  },
  'Weekly' => {
    'lastUpdated' => '1257423892',
    'message' => 'Semanal'
  },
  'Yearly' => {
    'lastUpdated' => '1257423902',
    'message' => 'Anual'
  },
  'add related link' => {
    'lastUpdated' => '1215707379',
    'message' => 'Adicionar nuevo Link'
  },
  'add/edit title' => {
    'lastUpdated' => '1215707424',
    'message' => 'Evento, Adicionar/Editar Variables de Plantilla Screen'
  },
  'assetName' => {
    'lastUpdated' => '1215707431',
    'message' => 'Evento'
  },
  'attachment.icon' => {
    'lastUpdated' => '1215707458',
    'message' => 'Un &iacute;cono mostrando el tipo de archivo de este adjunto.'
  },
  'attachment.name' => {
    'lastUpdated' => '1215707520',
    'message' => 'El nombre del primer adjunto encontrado enla publicaci&oacute;n.'
  },
  'attachment.url' => {
    'lastUpdated' => '1215707691',
    'message' => 'La URL para descargar el primer adjunto de la Publicaci&oacute;n.'
  },
  'attachment_loop' => {
    'lastUpdated' => '1215707939',
    'message' => 'Un bucle que contiene todas las im&aacute;genes y archivos adjuntos a esta Publicaci&oacute;n.'
  },
  'attachment_url' => {
    'lastUpdated' => '1215707985',
    'message' => 'La URL para descargar este adjunto.'
  },
  'attachments' => {
    'lastUpdated' => '1215707993',
    'message' => 'Adjuntos'
  },
  'attachments for event' => {
    'lastUpdated' => '1215708006',
    'message' => 'Adjuntos para este Evento'
  },
  'canEdit' => {
    'lastUpdated' => '1215708034',
    'message' => 'Esta variables es verdades si el usuario actual puede editar este evento.'
  },
  'dateSpan' => {
    'lastUpdated' => '1215708217',
    'message' => 'Una vista clara de fechas y tiempos iniciales y finales de este evento.'
  },
  'day' => {
    'lastUpdated' => '1257423910',
    'message' => 'día'
  },
  'delete' => {
    'lastUpdated' => '1215706748',
    'message' => 'Eliminar'
  },
  'description' => {
    'lastUpdated' => '1215708231',
    'message' => 'Descripci&oacute;n'
  },
  'description label' => {
    'lastUpdated' => '1215809312',
    'message' => 'Descripci&oacute;n'
  },
  'edit' => {
    'lastUpdated' => '1215706773',
    'message' => 'Editar'
  },
  'end' => {
    'lastUpdated' => '1215706791',
    'message' => 'Fin'
  },
  'end date' => {
    'lastUpdated' => '1215706812',
    'message' => 'Fecha Fin'
  },
  'endDate' => {
    'lastUpdated' => '1215706853',
    'message' => 'La fecha final de este evento.'
  },
  'endDateDayAbbr' => {
    'lastUpdated' => '1215708295',
    'message' => 'La abreviaci&oacute;n del nombre del d&iacute;a en que finaliza el Evento.'
  },
  'endDateDayName' => {
    'lastUpdated' => '1215708311',
    'message' => 'El nombre del d&iacute;a en que finaliza el Evento.'
  },
  'endDateDayOfMonth' => {
    'lastUpdated' => '1215708340',
    'message' => 'El d&iacute;a del mes en que finaliza este Evento, un n&uacute;mero del 1 al 31.'
  },
  'endDateDayOfWeek' => {
    'lastUpdated' => '1215708400',
    'message' => 'El d&iacute;a de la semana en que finaliza este Evento, un n&uacute;mero del 1 al 7.'
  },
  'endDateDmy' => {
    'lastUpdated' => '1215708853',
    'message' => 'El formato de la fecha final del Evento en dd-mm-yyyy, donde yyyy es el a&ntilde;o, mm es el mes y dd es el d&iacute;a.'
  },
  'endDateEpoch' => {
    'lastUpdated' => '1215709388',
    'message' => 'La fecha final de este Evento y el tiempo en formato de &eacute;poca.'
  },
  'endDateHms' => {
    'lastUpdated' => '1215709428',
    'message' => 'El formato del tiempo en que finaliza este Evento en hh:mm:ss, donde hh es la hora, mm es el minuto y ss es el segundo.'
  },
  'endDateHour' => {
    'lastUpdated' => '1215707213',
    'message' => 'Hora en que termina este evento.'
  },
  'endDateHour24' => {
    'lastUpdated' => '1215709474',
    'message' => 'La hora, en formato 24 horas, en que finaliza este Evento.'
  },
  'endDateHourM' => {
    'lastUpdated' => '1215709713',
    'message' => 'Dependiendo si el evento ocurre en la ma&ntilde;ana o en la tarde, cualquier cadena &quot;am&quot; o &quot;pm&quot;.'
  },
  'endDateMdy' => {
    'lastUpdated' => '1215709732',
    'message' => 'El formato de la fecha final del Evento en mm-dd-yyyy, donde yyyy es el a&ntilde;o, mm es el mes y dd es el d&iacute;a.'
  },
  'endDateMinute' => {
    'lastUpdated' => '1215709764',
    'message' => 'El minuto, con formato de dos d&iacute;gitos con los ceros, en que finaliza este evento.'
  },
  'endDateMonthAbbr' => {
    'lastUpdated' => '1215709812',
    'message' => 'La abreviaci&oacute;n del nombre del mes en que finaliza este Evento.'
  },
  'endDateMonthName' => {
    'lastUpdated' => '1215709869',
    'message' => 'El nombre del mes en que finaliza este Evento.'
  },
  'endDateSecond' => {
    'lastUpdated' => '1215709887',
    'message' => 'El segundo, con formato de dos d&iacute;gitos con los ceros, en que finaliza este evento.'
  },
  'endDateYear' => {
    'lastUpdated' => '1215709911',
    'message' => 'El a&ntilde;o en que finaliza este Evento, con 4 d&iacute;gitos.'
  },
  'endDateYmd' => {
    'lastUpdated' => '1215709943',
    'message' => 'El formato de la fecha final del Evento en yyyy-mm-dd, donde yyyy es el a&ntilde;o, mm es el mes y dd es el d&iacute;a.'
  },
  'endTime' => {
    'lastUpdated' => '1215709995',
    'message' => 'La fecha final de este Evento.'
  },
  'errors' => {
    'lastUpdated' => '1215706881',
    'message' => 'Errores!'
  },
  'event asset template variables body' => {
    'lastUpdated' => '1215710232',
    'message' => 'Cada activo proporcionan un conjunto de variables que la mayor parte de sus plantillas estan basadas en propiedades internas del activo. Algunas de estas variables puede ser &uacute;tiles, otras no.'
  },
  'event asset template variables title' => {
    'lastUpdated' => '1215710368',
    'message' => 'Variables de Plantilla del Activo Evento'
  },
  'event common template variables body' => {
    'lastUpdated' => '1215710410',
    'message' => 'Estas variables de plantilla son usadas por ambos el Evento y el Calendario.'
  },
  'event common template variables title' => {
    'lastUpdated' => '1215710487',
    'message' => 'Variables de plantilla Evento Com&uacute;n'
  },
  'event details' => {
    'lastUpdated' => '1215706894',
    'message' => 'Detalles del Evento'
  },
  'event title' => {
    'lastUpdated' => '1215706919',
    'message' => 'T&iacute;tulo del Evento'
  },
  'event view template variables body' => {
    'lastUpdated' => '1215710522',
    'message' => 'Estas variables de plantilla son usadas por las plantillas que muestran este evento a los usuarios.'
  },
  'event view template variables title' => {
    'lastUpdated' => '1215710581',
    'message' => 'Variables de Plantilla de Vista de Evento'
  },
  'exclude dates' => {
    'lastUpdated' => '1215710612',
    'message' => 'Excluir Fechas'
  },
  'feedId' => {
    'lastUpdated' => '1215710683',
    'message' => 'El identificador &uacute;nico para un iCal feed.'
  },
  'feedUid' => {
    'lastUpdated' => '1215710712',
    'message' => 'El lugar de este Evento.'
  },
  'filename' => {
    'lastUpdated' => '1215710260',
    'message' => 'El nombre de este adjunto.'
  },
  'first' => {
    'lastUpdated' => '1257424038',
    'message' => 'primer(a)'
  },
  'formAttachments' => {
    'lastUpdated' => '1215710752',
    'message' => 'Formulario HTML para adicionar o remover archivos para este Evento.'
  },
  'formCancel' => {
    'lastUpdated' => '1215710850',
    'message' => 'un bot&oacute;n HTML para cancelar la adici&oacute;n o edici&oacute;n de un evento.'
  },
  'formDescription' => {
    'lastUpdated' => '1215710880',
    'message' => 'Formulario HTML para entrar o editar la Descripci&oacute;n del Evento.'
  },
  'formEndDate' => {
    'lastUpdated' => '1215710907',
    'message' => 'Formulario HTML para entrar o editar la fecha final del Evento.'
  },
  'formEndTime' => {
    'lastUpdated' => '1215710941',
    'message' => 'Formulario HTML para entrar o editar el tiempo final del Evento.'
  },
  'formErrors' => {
    'lastUpdated' => '1215711011',
    'message' => 'Este bucle contiene cualquier error del proceso de los datos del formulario del Evento.'
  },
  'formFooter' => {
    'lastUpdated' => '1215711069',
    'message' => 'Formulario HTML para finalizar la Adici&oacute;n/Edici&oacute;n del Evento.'
  },
  'formGroupToView' => {
    'lastUpdated' => '1215711165',
    'message' => '<div id="result_box" dir="ltr">Formulario HTML para escoger qu&eacute; grupo puede ver este evento.</div>'
  },
  'formHeader' => {
    'lastUpdated' => '1215711250',
    'message' => 'Formulario HTML y JavaScript para iniciar la Adici&oacute;n/Edici&oacute;n del Evento.'
  },
  'formLocation' => {
    'lastUpdated' => '1215711305',
    'message' => 'Formulario HTML para entrar o editar el lugar del Evento.'
  },
  'formMenuTitle' => {
    'lastUpdated' => '1215711333',
    'message' => 'Formulario HTML para entrar o editar el T&iacute;tulo de Men&uacute; del Evento.'
  },
  'formRecurEnd' => {
    'lastUpdated' => '1215711428',
    'message' => 'Formulario HTML para entrar la fecha de cuando finaliza un evento repetitivo, si aplica.'
  },
  'formRecurPattern' => {
    'lastUpdated' => '1215711476',
    'message' => 'HTML y Javascript para un formulario que define como un evento se repite.'
  },
  'formRecurStart' => {
    'lastUpdated' => '1215711401',
    'message' => 'Formulario HTML de fechas para entrar la primera fecha o repetici&oacute;n&nbsp; de un evento.'
  },
  'formRelatedLinks' => {
    'lastUpdated' => '1215711298',
    'message' => 'Un formulario de texto HTML para entrar en las URL de sitios web con m&aacute;s informaci&oacute;n sobre este evento. Enlaces individuales ser&iacute;an adicionados uno por l&iacute;nea.'
  },
  'formSave' => {
    'lastUpdated' => '1215711177',
    'message' => 'C&oacute;digo HTML de un bot&oacute;n para guardar los datos del evento'
  },
  'formStartDate' => {
    'lastUpdated' => '1215711108',
    'message' => 'Formulario HTML para la entrada o la edici&oacute;n de la fecha de inicio del evento.'
  },
  'formStartTime' => {
    'lastUpdated' => '1215711057',
    'message' => 'Formulario HTML para la entrada o la edici&oacute;n de la hora de inicio del evento.'
  },
  'formSynopsis' => {
    'lastUpdated' => '1257423941',
    'message' => 'Formulario HTML para ingresar o modificar el Resumen Sinóptico del Evento.'
  },
  'formTime' => {
    'lastUpdated' => '1215710948',
    'message' => 'Un formulario HTML para manipular&nbsp; la hora de inicio y final de un evento. Tiene presete todo el d&iacute;a, tiempo no espec&iacute;fico, o un tiempo inicial o final espec&iacute;fico. '
  },
  'formTitle' => {
    'lastUpdated' => '1215710718',
    'message' => 'HTML para introducir o editar el t&iacute;tulo del evento.'
  },
  'formUserDefinedN' => {
    'lastUpdated' => '1215710649',
    'message' => 'Para cada uno de los 5 campos Definido por el usuario, un formulario de widgets para una sola l&iacute;nea de texto.<br /> '
  },
  'formUserDefinedN_float' => {
    'lastUpdated' => '1215710568',
    'message' => 'Para cada uno de los 5 campos Definido por el usuario, un formulario de widgets para un float.<br /> '
  },
  'formUserDefinedN_htmlarea' => {
    'lastUpdated' => '1215710492',
    'message' => 'Para cada uno de los 5 campos Definidos por el usuario, un formulario de widgets para una &aacute;rea de HTML.<br /> '
  },
  'formUserDefinedN_textarea' => {
    'lastUpdated' => '1215710426',
    'message' => 'Para cada uno de los 5 campos Definido por el usuario, un formulario de widgets para una &aacute;rea de texto.'
  },
  'formUserDefinedN_yesNo' => {
    'lastUpdated' => '1215710326',
    'message' => 'Para cada uno de los 5 campos Definidos por el usuario, un formulario de widgets para un campo s&iacute; / no'
  },
  'fourth' => {
    'lastUpdated' => '1257424047',
    'message' => 'cuarto(a)'
  },
  'group to view' => {
    'lastUpdated' => '1215709762',
    'message' => 'Grupo para ver este evento.'
  },
  'groupToView' => {
    'lastUpdated' => '1215709742',
    'message' => 'El ID del grupo que est&aacute; permitido para ver este evento.'
  },
  'icon' => {
    'lastUpdated' => '1215709644',
    'message' => 'El icono representando el tipo de archivo de este adjunto.'
  },
  'image.thumbnail' => {
    'lastUpdated' => '1215709590',
    'message' => 'Un vista en miniatura para la imagen adjuntada a la publicaci&oacute;n.'
  },
  'image.url' => {
    'lastUpdated' => '1215709527',
    'message' => 'La URL de la primera imagen adjuntada a la publicaci&oacute;n.'
  },
  'include dates' => {
    'lastUpdated' => '1215709485',
    'message' => 'Incluir Fechas'
  },
  'invalid end date' => {
    'lastUpdated' => '1302872715',
    'message' => 'Fecha de final es inválida. Por favor ingrese una fecha válida de la forma \'AAAA-MM-DD\'.'
  },
  'invalid start date' => {
    'lastUpdated' => '1302872723',
    'message' => 'Fecha de inicio es inválida. Por favor ingrese una fecha válida de la forma \'AAAA-MM-DD\'.'
  },
  'isAllDay' => {
    'lastUpdated' => '1215709225',
    'message' => 'Un condicional que es verdadero si este evento ha sido configurado para realizarse todo el d&iacute;a.'
  },
  'isImage' => {
    'lastUpdated' => '1215709116',
    'message' => 'Un condicional indicando si este adjunto es una imagen.'
  },
  'isOneDay' => {
    'lastUpdated' => '1215709269',
    'message' => 'Un condicional que es verdadero si este evento comienza y termina sobre el mismo d&iacute;a.'
  },
  'isPublic' => {
    'lastUpdated' => '1215709468',
    'message' => 'Un condicional que ser&iacute;a verdadero si el grupo para ver este evento es todos.'
  },
  'last' => {
    'lastUpdated' => '1257424055',
    'message' => 'último(a)'
  },
  'link description' => {
    'lastUpdated' => '1215709402',
    'message' => 'Enlace Desc'
  },
  'link view group' => {
    'lastUpdated' => '1215709375',
    'message' => 'Ver Grupo'
  },
  'linkUrl' => {
    'lastUpdated' => '1215710188',
    'message' => '<div id="result_box" dir="ltr">Un URL de la serie de enlaces relacionados</div>'
  },
  'locale' => {
    'lastUpdated' => '1215710319',
    'message' => 'en_US'
  },
  'location' => {
    'lastUpdated' => '1215706979',
    'message' => 'Lugar'
  },
  'message' => {
    'lastUpdated' => '1215709052',
    'message' => 'Un mensaje de error.'
  },
  'next event' => {
    'lastUpdated' => '1215708679',
    'message' => 'Siguiente Evento'
  },
  'nextUrl' => {
    'lastUpdated' => '1215708529',
    'message' => 'Una URL que toma el usuario para el siguiente evento en el calendario, por fecha y tiempo.'
  },
  'occurences' => {
    'lastUpdated' => '1257423983',
    'message' => 'ocurrencias'
  },
  'of' => {
    'lastUpdated' => '1257423989',
    'message' => 'de'
  },
  'prevUrl' => {
    'lastUpdated' => '1215708650',
    'message' => 'Una URL que toma el usuario para el anterior evento en el calendario, por fecha y tiempo.'
  },
  'previous event' => {
    'lastUpdated' => '1215708665',
    'message' => 'Evento Anterior'
  },
  'print' => {
    'lastUpdated' => '1215707012',
    'message' => 'Imprimir'
  },
  'recurId' => {
    'lastUpdated' => '1215709803',
    'message' => 'Un &uacute;nico identificador para la recurrencia de este evento en la base de datos.'
  },
  'recurrence' => {
    'lastUpdated' => '1215709870',
    'message' => 'Repeticiones'
  },
  'recurrence pattern' => {
    'lastUpdated' => '1215709899',
    'message' => 'Patr&oacute;n de repeticiones'
  },
  'recurrence range' => {
    'lastUpdated' => '1215709912',
    'message' => 'Rango de repeticiones'
  },
  'related material' => {
    'lastUpdated' => '1215709926',
    'message' => 'Material Relacionado'
  },
  'relatedLinks' => {
    'lastUpdated' => '1215710004',
    'message' => 'Este bucle contiene todos los enlaces de este evento del conjunto de enlaces relacionados'
  },
  'relatedLinks assetVar' => {
    'lastUpdated' => '1215710117',
    'message' => 'El original, sin procesar, enlaces relacionados de el formulario. Esto ser&aacute; todos los enlaces en una cadena unida por nuevas l&iacute;neas.'
  },
  'scheduled' => {
    'lastUpdated' => '1215710138',
    'message' => 'Programado'
  },
  'second' => {
    'lastUpdated' => '1257424063',
    'message' => 'segundo(a)'
  },
  'short title' => {
    'lastUpdated' => '1215707348',
    'message' => 'T&iacute;tulo Corto.'
  },
  'start' => {
    'lastUpdated' => '1215706312',
    'message' => 'Inicio'
  },
  'start date' => {
    'lastUpdated' => '1215706997',
    'message' => 'Fecha de Inicio'
  },
  'startDate' => {
    'lastUpdated' => '1215706085',
    'message' => 'La fecha de inicio de este evento.'
  },
  'startDateDayAbbr' => {
    'lastUpdated' => '1215707336',
    'message' => 'La abreviatura del nombre del d&iacute;a en que comienza el Evento.'
  },
  'startDateDayName' => {
    'lastUpdated' => '1215707317',
    'message' => 'El nombre del d&iacute;a en que comienza el Evento.'
  },
  'startDateDayOfMonth' => {
    'lastUpdated' => '1215707284',
    'message' => 'El d&iacute;a del mes en que comienza este Evento, un n&uacute;mero del 1 al 31.'
  },
  'startDateDayOfWeek' => {
    'lastUpdated' => '1215707242',
    'message' => 'El dia de la semana en que comienza este Evento, un n&uacute;mero del 1 al 7.'
  },
  'startDateDmy' => {
    'lastUpdated' => '1215707209',
    'message' => 'El formato de la fecha de inicio del Evento en dd-mm-yyyy, donde yyyy es el a&ntilde;o, mm es el mes y dd es el d&iacute;a.'
  },
  'startDateEpoch' => {
    'lastUpdated' => '1215707148',
    'message' => 'La fecha de inicio de este Evento y el tiempo en formato de &eacute;poca.'
  },
  'startDateHms' => {
    'lastUpdated' => '1215707014',
    'message' => 'El formato del tiempo en que comienza este Evento en hh:mm:ss, donde hh es la hora, mm es el minuto y ss es el segundo.'
  },
  'startDateHour' => {
    'lastUpdated' => '1215706903',
    'message' => 'La hora en que comienta este Evento.'
  },
  'startDateHour24' => {
    'lastUpdated' => '1215706832',
    'message' => 'La hora, en formato 24 horas, en que comienza este Evento.'
  },
  'startDateHourM' => {
    'lastUpdated' => '1215706806',
    'message' => 'Dependiendo si el evento ocurre en la ma&ntilde;ana o en la tarde, cualquier cadena &quot;am&quot; o &quot;pm&quot;.'
  },
  'startDateMdy' => {
    'lastUpdated' => '1215706676',
    'message' => 'El formato de la fecha de inicio del Evento en mm-dd-yyyy, donde yyyy es el a&ntilde;o, mm es el mes y dd es el d&iacute;a.'
  },
  'startDateMinute' => {
    'lastUpdated' => '1215706630',
    'message' => 'El minuto, con formato de dos d&iacute;gitos con los ceros, en que comienza este evento.'
  },
  'startDateMonthAbbr' => {
    'lastUpdated' => '1215706602',
    'message' => 'La abreviatura del nombre del mes en que comienza este Evento.'
  },
  'startDateMonthName' => {
    'lastUpdated' => '1215706575',
    'message' => 'El nombre del mes en que comienza este Evento.'
  },
  'startDateSecond' => {
    'lastUpdated' => '1215706556',
    'message' => 'El segundo, con formato de dos d&iacute;gitos con los ceros, en que comienza este evento.'
  },
  'startDateYear' => {
    'lastUpdated' => '1215706493',
    'message' => '<div id="result_box" dir="ltr">El a&ntilde;o en que comienza este evento, con 4 d&iacute;gitos.</div>'
  },
  'startDateYmd' => {
    'lastUpdated' => '1215706441',
    'message' => 'El formato de la fecha de inicio del Evento en yyyy-mm-dd, donde yyyy es el a&ntilde;o, mm es el mes y dd es el d&iacute;a.'
  },
  'startTime' => {
    'lastUpdated' => '1215706374',
    'message' => 'Fecha de inicio de este Evento.'
  },
  'tab event' => {
    'lastUpdated' => '1215706323',
    'message' => 'Evento'
  },
  'third' => {
    'lastUpdated' => '1257424072',
    'message' => 'tercer(a)'
  },
  'thumbnail' => {
    'lastUpdated' => '1215706301',
    'message' => 'Un thumbnail de este adjunto, si aplica.'
  },
  'time' => {
    'lastUpdated' => '1215706013',
    'message' => 'Tiempo'
  },
  'url' => {
    'lastUpdated' => '1215706231',
    'message' => 'La URL para este Evento.'
  },
  'urlDay' => {
    'lastUpdated' => '1215706214',
    'message' => 'Una URL para mostrar todos los Eventos del mismo dia de este Evendo del Calendario.'
  },
  'urlDelete' => {
    'lastUpdated' => '1252515529',
    'message' => 'El URL para eliminar este Evento.'
  },
  'urlEdit' => {
    'lastUpdated' => '1252515540',
    'message' => 'El URL para editar este Evento.'
  },
  'urlList' => {
    'lastUpdated' => '1252515558',
    'message' => 'El URL para mostrar el Evento como una lista, en lugar de como calendario.'
  },
  'urlMonth' => {
    'lastUpdated' => '1215706182',
    'message' => 'Una URL para mostrar todos los Eventos en el mismo mes de este Evento del Calendario.'
  },
  'urlParent' => {
    'lastUpdated' => '1252515567',
    'message' => 'El URL al Calendario que contiene este Evento.'
  },
  'urlPrint' => {
    'lastUpdated' => '1252515583',
    'message' => 'El URL para presentar este Evento con la Plantilla para Imprimir.'
  },
  'urlSearch' => {
    'lastUpdated' => '1215706120',
    'message' => '<div id="result_box" dir="ltr">Una URL a la b&uacute;squeda para el calendario que contiene este evento.</div>'
  },
  'urlWeek' => {
    'lastUpdated' => '1215706020',
    'message' => 'Una URL para mostrar todos los Eventos en la misma semana de este Evento del Calendario.'
  },
  'week on' => {
    'lastUpdated' => '1257424023',
    'message' => 'semana de'
  }
}
;

1;
